<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>FileControl</name>
    <message>
        <location filename="../src/filecontrol.cpp" line="781"/>
        <source>Fullscreen</source>
        <translation>전체화면</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="785"/>
        <source>Exit fullscreen</source>
        <translation>전체화면 종료</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="789"/>
        <source>Extract text</source>
        <translation>텍스트 추출</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="793"/>
        <source>Slide show</source>
        <translation>슬라이드 표시</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="797"/>
        <source>Rename</source>
        <translation>이름 변경</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="801"/>
        <source>Copy</source>
        <translation>복사</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="805"/>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="809"/>
        <source>Rotate clockwise</source>
        <translation>시계 방향으로 회전</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="813"/>
        <source>Rotate counterclockwise</source>
        <translation>시계 반대 방향으로 회전</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="817"/>
        <source>Set as wallpaper</source>
        <translation>바탕화면으로 설정</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="821"/>
        <source>Display in file manager</source>
        <translation>파일 관리도구에 표시</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="825"/>
        <source>Image info</source>
        <translation>이미지 정보</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="829"/>
        <source>Previous</source>
        <translation>이전</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="833"/>
        <source>Next</source>
        <translation>다음</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="837"/>
        <source>Zoom in</source>
        <translation>확대</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="841"/>
        <source>Zoom out</source>
        <translation>축소</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="845"/>
        <source>Open</source>
        <translation>열기</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="849"/>
        <source>Print</source>
        <translation>인쇄</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="873"/>
        <source>Image Viewing</source>
        <translation>이미지 보는 중</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="877"/>
        <source>Help</source>
        <translation>도움말</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="881"/>
        <source>Display shortcuts</source>
        <translation>단축키 표시</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="889"/>
        <source>Settings</source>
        <translation>설정</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="897"/>
        <source>Select all</source>
        <translation>모두 선택</translation>
    </message>
    <message>
        <location filename="../src/filecontrol.cpp" line="905"/>
        <source>Live Text</source>
        <translation>실시간 텍스트</translation>
    </message>
</context>
<context>
    <name>InformationDialog</name>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="74"/>
        <source>Basic info</source>
        <translation>기본 정보</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="98"/>
        <source>Size</source>
        <translation>크기</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="124"/>
        <source>Date captured</source>
        <translation>캡처된 날짜</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="131"/>
        <source>Date modified</source>
        <translation>수정된 날짜</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="141"/>
        <source>Details</source>
        <translation>상세 정보</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="154"/>
        <source>Aperture</source>
        <translation>조리개</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="162"/>
        <source>Exposure program</source>
        <translation>노출 프로그램</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="169"/>
        <source>Focal length</source>
        <translation>초점 거리</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="175"/>
        <source>ISO</source>
        <translation>ISO</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="182"/>
        <source>Exposure mode</source>
        <translation>노출 모드</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="188"/>
        <source>Exposure time</source>
        <translation>노출 시간</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="194"/>
        <source>Flash</source>
        <translation>플래시</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="201"/>
        <source>Flash compensation</source>
        <translation>플래시 보정</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="214"/>
        <source>Colorspace</source>
        <translation>색상공간</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="221"/>
        <source>Metering mode</source>
        <translation>미터링 모드</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="228"/>
        <source>White balance</source>
        <translation>화이트 밸런스</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="246"/>
        <source>Lens model</source>
        <translation>렌즈 모델</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="87"/>
        <source>File name</source>
        <translation>파일 이름</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="105"/>
        <source>Dimensions</source>
        <translation>치수</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="112"/>
        <source>Type</source>
        <translation>형식</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="207"/>
        <source>Max aperture</source>
        <translation>최대 조리개</translation>
    </message>
    <message>
        <location filename="../qml/InformationDialog/InformationDialog.qml" line="239"/>
        <source>Device model</source>
        <translation>장치 모델</translation>
    </message>
</context>
<context>
    <name>LiveTextWidget</name>
    <message>
        <location filename="../qml/LiveText/LiveTextWidget.qml" line="155"/>
        <source>Copy (Ctrl+C)</source>
        <translation>복사 (Ctrl+C)</translation>
    </message>
    <message>
        <location filename="../qml/LiveText/LiveTextWidget.qml" line="172"/>
        <source>Select all (Ctrl+A)</source>
        <translation>모두 선택 (Ctrl+A)</translation>
    </message>
</context>
<context>
    <name>MainStack</name>
    <message>
        <location filename="../qml/MainStack.qml" line="129"/>
        <source>Select pictures</source>
        <translation>사진 선택</translation>
    </message>
</context>
<context>
    <name>NonexistImageDelegate</name>
    <message>
        <location filename="../qml/ImageDelegate/NonexistImageDelegate.qml" line="43"/>
        <source>Image file not found</source>
        <translation>이미지 파일을 찾을 수 없음</translation>
    </message>
</context>
<context>
    <name>OpenImageWidget</name>
    <message>
        <location filename="../qml/OpenImageWidget.qml" line="35"/>
        <source>Open Image</source>
        <translation>이미지 열기</translation>
    </message>
</context>
<context>
    <name>PropertyActionItemDelegate</name>
    <message>
        <location filename="../qml/InformationDialog/PropertyActionItemDelegate.qml" line="95"/>
        <source>The file already exists, please use another name</source>
        <translation>이 파일은 이미 존재합니다. 다른 이름을 사용하세요</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../main.cpp" line="48"/>
        <source>Image Viewer</source>
        <translation>이미지 보기도구</translation>
    </message>
    <message>
        <location filename="../src/unionimage/unionimage_global.h" line="102"/>
        <source>day</source>
        <translation>일</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="51"/>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>이미지 보기도구는 인기있는 인터페이스와 원활한 성능을 갖춘 이미지보기 도구입니다.</translation>
    </message>
</context>
<context>
    <name>ReName</name>
    <message>
        <location filename="../qml/ReName.qml" line="70"/>
        <source>Input a new name</source>
        <translation>새 이름 입력</translation>
    </message>
    <message>
        <location filename="../qml/ReName.qml" line="85"/>
        <source>The file already exists, please use another name</source>
        <translation>이 파일은 이미 존재합니다. 다른 이름을 사용하세요</translation>
    </message>
    <message>
        <location filename="../qml/ReName.qml" line="141"/>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <location filename="../qml/ReName.qml" line="123"/>
        <source>Confirm</source>
        <translation>확인</translation>
    </message>
</context>
<context>
    <name>RemoveDialog</name>
    <message>
        <location filename="../qml/Dialog/RemoveDialog.qml" line="71"/>
        <source>Cannot move "%1" to the trash. Do you want to permanently delete it?</source>
        <translation>"%1"를 쓰레기통으로 이동할 수 없습니다. 영구히 삭제하시겠습니까?</translation>
    </message>
    <message>
        <location filename="../qml/Dialog/RemoveDialog.qml" line="89"/>
        <source>This action cannot be undone</source>
        <translation>이 작업은 되돌릴 수 없습니다</translation>
    </message>
    <message>
        <location filename="../qml/Dialog/RemoveDialog.qml" line="101"/>
        <source>Cancel</source>
        <translation>취소</translation>
    </message>
    <message>
        <location filename="../qml/Dialog/RemoveDialog.qml" line="111"/>
        <source>Confirm</source>
        <translation>확인</translation>
    </message>
</context>
<context>
    <name>SliderShow</name>
    <message>
        <location filename="../qml/SliderShow.qml" line="155"/>
        <source>Previous</source>
        <translation>이전</translation>
    </message>
    <message>
        <location filename="../qml/SliderShow.qml" line="172"/>
        <source>Pause</source>
        <translation>일시중지</translation>
    </message>
    <message>
        <location filename="../qml/SliderShow.qml" line="172"/>
        <source>Play</source>
        <translation>재생</translation>
    </message>
    <message>
        <location filename="../qml/SliderShow.qml" line="188"/>
        <source>Next</source>
        <translation>다음</translation>
    </message>
    <message>
        <location filename="../qml/SliderShow.qml" line="203"/>
        <source>Exit</source>
        <translation>종료</translation>
    </message>
</context>
<context>
    <name>ThumbnailListView</name>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="173"/>
        <source>Next</source>
        <translation>다음</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="148"/>
        <source>Previous</source>
        <translation>이전</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="209"/>
        <source>Original size</source>
        <translation>원본 크기</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="227"/>
        <source>Fit to window</source>
        <translation>창에 맞춤</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="244"/>
        <source>Rotate</source>
        <translation>회전</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="517"/>
        <source>Extract text</source>
        <translation>텍스트 추출</translation>
    </message>
    <message>
        <location filename="../qml/ThumbnailListView.qml" line="536"/>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
</context>
<context>
    <name>ViewRightMenu</name>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="38"/>
        <source>Fullscreen</source>
        <translation>전체화면</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="38"/>
        <source>Exit fullscreen</source>
        <translation>전체화면 종료</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="57"/>
        <source>Print</source>
        <translation>인쇄</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="76"/>
        <source>Extract text</source>
        <translation>텍스트 추출</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="96"/>
        <source>Slide show</source>
        <translation>슬라이드 표시</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="117"/>
        <source>Copy</source>
        <translation>복사</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="137"/>
        <source>Rename</source>
        <translation>이름 변경</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="156"/>
        <source>Delete</source>
        <translation>삭제</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="183"/>
        <source>Rotate clockwise</source>
        <translation>시계 방향으로 회전</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="203"/>
        <source>Rotate counterclockwise</source>
        <translation>시계 반대 방향으로 회전</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="231"/>
        <source>Show navigation window</source>
        <translation>탐색 창 표시</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="231"/>
        <source>Hide navigation window</source>
        <translation>탐색 창 숨기기</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="243"/>
        <source>Set as wallpaper</source>
        <translation>바탕화면으로 설정</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="263"/>
        <source>Display in file manager</source>
        <translation>파일 관리도구에 표시</translation>
    </message>
    <message>
        <location filename="../qml/ViewRightMenu.qml" line="280"/>
        <source>Image info</source>
        <translation>이미지 정보</translation>
    </message>
</context>
<context>
    <name>ViewTopTitle</name>
    <message>
        <location filename="../qml/ViewTopTitle.qml" line="189"/>
        <source>Image Viewer is an image viewing tool with fashion interface and smooth performance.</source>
        <translation>이미지 보기도구는 인기있는 인터페이스와 원활한 성능을 갖춘 이미지보기 도구입니다.</translation>
    </message>
    <message>
        <location filename="../qml/ViewTopTitle.qml" line="191"/>
        <source>Image Viewer</source>
        <translation>이미지 보기도구</translation>
    </message>
    <message>
        <location filename="../qml/ViewTopTitle.qml" line="167"/>
        <source>Open image</source>
        <translation>이미지 열기</translation>
    </message>
</context>
</TS>
